<?php
 /**
 * Pagination.class.php
 * Last Modify: May 2012
 * By Narong Rammanee
 */
 
class Pagination
{	
	/**
	 * Previous page constant
	 * @var string
	 */
	const PREV = '&lsaquo; Prev';
	
	/**
	 * First page constant
	 * @var string
	 */
	const FIRST = '&laquo; First';
	
	/**
	 * Next page constant
	 * @var string
	 */
	const NEXT = 'Next &rsaquo;';
	
	/**
	 * Last page constant
	 * @var string
	 */
	const LAST = 'Last &raquo;';
	/**
	 * All page
	 * @var interger
	 */
	public $totalPage;
	
	/**
	 * SQL offset
	 * @var interger
	 */
	public $offset;
	
	/**
	 * URL page
	 * @var unknown_type
	 */
	private $link;
	
	/**
	 * All row of data
	 * @var integer
	 */
	private $records;
	
	/**
	 * Current page
	 * @var interger
	 */
	private $curPage;
	
	/**
	 * Per page
	 * @var integer
	 */
	private $perPage;
	
	/**
	 * Scroll page
	 * @var integer
	 */
	private $scroll = 18;
  
	/** 
	 * Initialization
	 * @param string link
	 * @param integer records
	 * @param integer curPage
	 * @param integer perPage
	 */
	public function __construct($link, $records, $curPage, $perPage)
	{	
  		$this->link    = $link;
  		$this->records = $records;
  		$this->curPage = $curPage;
  		$this->perPage = $perPage;
  		$this->totalPage = ($this->records) ? ceil($this->records / $this->perPage) : 0;
  		$this->curPage = (!is_numeric($this->curPage)) ? 1 : $this->curPage;
		$this->offset   = ($this->totalPage <= 1) ? 0 : ($this->curPage - 1) * $this->perPage;	
	}
  
 	/**
	 * Create Pagination
	 * 
	 * @return void
	 */ 
	public function render()
	{
		if(!$html = self::compilePagination())
			throw new Exception( 'Error obtaining Pagination!' );
		
		echo $html;
	}
  
	/**
	 * define private 'compilePagination()' method
	 * 
	 * @return complete Pagination
	 */
	private function compilePagination()
	{
		$html = '<p class="css-pager">';
		if($this->totalPage > 1 && $this->curPage > 1) {
			$html .= '<a href="' . $this->link . '1">' . self::FIRST . '</a>';
		}
		if($this->totalPage > 1 && $this->curPage > 1) {
			$html .= '<a href="' . $this->link . ($this->curPage - 1) . '">' . self::PREV . '</a>';
		}
		
		if($this->totalPage <= $this->scroll) {
			if($this->records <= $this->perPage) {
				$startPage = 1;
				$stopPage  = $this->totalPage;
			} else {
				$startPage = 1;
				$stopPage  = $this->totalPage;
			}
		} else {
			if($this->curPage < intval($this->scroll / 2) + 1) {
				$startPage = 1; 
				$stopPage  = $this->scroll;
			} else {
				$startPage = $this->curPage - intval($this->scroll / 2);
				$stopPage  = $this->curPage + intval($this->scroll / 2);
			if($stopPage > $this->totalPage) $stopPage = $this->totalPage;
			}
		}
		if ($this->totalPage > 1) {
			for ($i = $startPage; $i <= $stopPage; $i++) {
				if ($i == $this->curPage) {
					$html .= '<span class="current_page">' . $i . '</span>';
				} else {
					$html .= '<a href="'.$this->link.$i.'">' . $i . '</a>';
				}
			}
		}
	
		if($this->curPage < $this->totalPage) {
			$html .= '<a href="' . $this->link . ($this->curPage + 1) . '">' . self::NEXT . '</a>';
		}
		if($this->curPage < $this->totalPage) {
			$html .= '<a href="' . $this->link . $this->totalPage . '">' . self::LAST . '</a>';
		}
		
		return $html.'</p>';
	}
}
